<?php
/**
 * @package CepCerto
 */
/*
Plugin Name: CepCerto Cálculo de Frete dos Correios
Description: Utilize o serviço CepCerto para calcular automaticamente o frete dos Correios, adicione facilmente o formulário de cálculo de frete em qualquer página ou post usando o shortcode [cepcerto_form]. 
Version: 1.0.2
Requires at least: 4.0
Tested up to: 6.6.1
Requires PHP: 5.6.20
Author: CepCerto
Author URI: https://cepcerto.com
License: GPLv2 or later
Text Domain: cepcerto-calculo-frete
*/

// Adiciona o charset UTF-8 ao cabeçalho
function cep_certo_add_meta_charset() {
    echo '<meta charset="UTF-8">';
}
add_action('wp_head', 'cep_certo_add_meta_charset');

// Adiciona os links do WhatsApp, "Como Funciona", "CEP de Origem" e "Seja Premium" ao plugin
add_filter('plugin_row_meta', 'cep_certo_add_atalho', 10, 2);
function cep_certo_add_atalho($plugin_meta, $plugin_file) {
    if ($plugin_file == plugin_basename(__FILE__)) {
        // Link para o WhatsApp
        $whatsapp_link = sprintf(
            '<span class="plugin-description">
                <a href="%s" target="_blank">
                    %s
                </a>
            </span>',
            esc_url('https://wa.me/5517920008366'),
            esc_html__('Contato pelo WhatsApp', 'cep-certo-calculo-frete')
        );

        // Link para a página "Como Funciona"
        $como_funciona_link = sprintf(
            '<span class="plugin-description">
                <a href="%s">
                    %s
                </a>
            </span>',
            esc_url(admin_url('admin.php?page=cep-certo-como-funciona')), // Link para a página do admin
            esc_html__('Como Funciona', 'cep-certo-calculo-frete')
        );

        // Link para a página "CEP de Origem"
        $cep_origem_link = sprintf(
            '<span class="plugin-description">
                <a href="%s">
                    %s
                </a>
            </span>',
            esc_url(admin_url('admin.php?page=cep-certo-cep-origem')), // Link para a página do admin
            esc_html__('CEP de Origem', 'cep-certo-calculo-frete')
        );

        // Link para a página "Seja Premium"
        $seja_premium_link = sprintf(
            '<span class="plugin-description">
                <a href="%s">
                    %s
                </a>
            </span>',
            esc_url(admin_url('admin.php?page=cep-certo-premium')), // Link para a página do admin
            esc_html__('Seja Premium', 'cep-certo-calculo-frete')
        );

        // Adiciona os links ao array $plugin_meta
        $plugin_meta[] = $whatsapp_link;
        $plugin_meta[] = $como_funciona_link;
        $plugin_meta[] = $cep_origem_link;
        $plugin_meta[] = $seja_premium_link;
    }
    return $plugin_meta;
}

// Enfileira o CSS e o JS em todas as páginas do plugin
function cep_certo_enqueue_assets() {
    // Enfileira o jQuery, que já vem com o WordPress
    wp_enqueue_script('jquery');

    // Enfileira o CSS em todas as páginas do plugin
    wp_enqueue_style(
        'cep-certo-styles', 
        plugin_dir_url(__FILE__) . 'css/style.css'
    );

    // Enfileira o JS em todas as páginas do plugin com dependência do jQuery
    wp_enqueue_script(
        'cep-certo-script', 
        plugin_dir_url(__FILE__) . 'js/script.js', 
        array('jquery'),  // Declara dependência de jQuery
        '1.0.0', 
        true // Carrega o script no final da página
    );

    // Passa a URL do admin-ajax.php para o script JS
    wp_localize_script('cep-certo-script', 'cepcerto_ajax', array(
        'ajaxurl' => admin_url('admin-ajax.php')
    ));
}
add_action('wp_enqueue_scripts', 'cep_certo_enqueue_assets');
add_action('admin_enqueue_scripts', 'cep_certo_enqueue_assets');

// Função de ativação do plugin para gerar o hash e salvar no banco, se ainda não existir
function cep_certo_ativar() {
    // Verifica se a opção 'cepcerto_chave' já existe
    if (!get_option('cepcerto_chave')) {
        // Gera um hash aleatório de 40 caracteres (letras e números minúsculos)
        $hash = bin2hex(random_bytes(20)); // Gera 20 bytes (40 caracteres hexadecimais)

        // Adiciona a opção no banco de dados do WordPress
        add_option('cepcerto_chave', $hash);

        // Dados a serem enviados para o outro servidor
        $nome = get_bloginfo('name'); // Nome do site (ou outro valor desejado)
        $email = get_option('admin_email'); // E-mail do administrador do site
        $site = get_bloginfo('url'); // URL do site

        // URL do script PHP no outro servidor
        $url = 'https://cepcerto.com/cadastro-wp/index.php'; // Atualize com a URL correta

        // Array de dados a serem enviados via POST
        $body = array(
            'name' => $nome,
            'email' => $email,
            'site' => $site,
            'hash' => $hash
        );

        // Opções de requisição
        $options = array(
            'body' => $body,
            'timeout' => 15,
            'redirection' => 5,
            'blocking' => true,
            'headers' => array(),
            'cookies' => array(),
        );

        // Envia a requisição POST para o servidor remoto
        $response = wp_remote_post($url, $options);

        // Verifica se a requisição foi bem-sucedida
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            error_log("Erro ao enviar os dados: $error_message");
        } else {
            error_log('Dados enviados com sucesso.');
        }
    }
}
register_activation_hook(__FILE__, 'cep_certo_ativar');

// Cria o menu principal e os submenus na barra lateral do WordPress
add_action('admin_menu', 'cep_certo_add_plugin_menu');
function cep_certo_add_plugin_menu() {
    // Menu principal
    add_menu_page(
        esc_html__('CepCerto Cálculo de Frete', 'cep-certo-calculo-frete'),
        esc_html__('CepCerto', 'cep-certo-calculo-frete'),
        'manage_options',
        'cep-certo',
        'cep_certo_render_main_page',
        'dashicons-admin-site',
        20
    );

    // Remove o submenu duplicado automaticamente
    add_action('admin_init', 'cep_certo_remove_default_submenu');

    // Submenu para "Como Funciona"
    add_submenu_page(
        'cep-certo',  // Slug do menu pai
        esc_html__('Como funciona', 'cep-certo-calculo-frete'),  // Título da página
        esc_html__('Como funciona', 'cep-certo-calculo-frete'),  // Texto do submenu
        'manage_options',  // Capacidade necessária
        'cep-certo-como-funciona',  // Slug da página "Como Funciona"
        'cep_certo_render_como_funciona_page'  // Função para renderizar a página
    );

    // Submenu para "CEP de Origem"
    add_submenu_page(
        'cep-certo',
        esc_html__('Cep de origem', 'cep-certo-calculo-frete'),
        esc_html__('Cep de origem', 'cep-certo-calculo-frete'),
        'manage_options',
        'cep-certo-cep-origem',
        'cep_certo_render_cep_origem_page'
    );

    // Submenu para "Premium"
    add_submenu_page(
        'cep-certo',
        esc_html__('Premium', 'cep-certo-calculo-frete'),
        esc_html__('Premium', 'cep-certo-calculo-frete'),
        'manage_options',
        'cep-certo-premium',
        'cep_certo_render_premium_page'
    );
}

// Remove o submenu duplicado automaticamente criado pelo WordPress
function cep_certo_remove_default_submenu() {
    remove_submenu_page('cep-certo', 'cep-certo');
}

// Função para renderizar a página principal
function cep_certo_render_main_page() {
    echo '<div class="wrap">';
    echo '<h1>' . esc_html__('Página Principal', 'cep-certo-calculo-frete') . '</h1>';
    echo '<p>' . esc_html__('Bem-vindo à página principal do plugin CepCerto.', 'cep-certo-calculo-frete') . '</p>';
    echo '</div>';
}

// Função para renderizar a página "Como Funciona"
function cep_certo_render_como_funciona_page() {
    echo '<div class="wrap">';
    // Caminho para o arquivo apresentacao.php
    $apresentacao_file = plugin_dir_path(__FILE__) . 'apresentacao/apresentacao.php';
    
    if (file_exists($apresentacao_file)) {
        include($apresentacao_file);
    } else {
        echo '<p>' . esc_html__('O arquivo apresentacao.php não foi encontrado.', 'cep-certo-calculo-frete') . '</p>';
    }
    echo '</div>';
}

// Função para renderizar a página de CEP de Origem
function cep_certo_render_cep_origem_page() {
    echo '<div class="wrap">';
    // Caminho para o arquivo form-cep-origem.php
    $cep_origem_file = plugin_dir_path(__FILE__) . 'cep-origem/form-ceporigem.php';
    
    if (file_exists($cep_origem_file)) {
        include($cep_origem_file);
        
    } else {
        echo '<p>' . esc_html__('O arquivo form-cep-origem.php não foi encontrado.', 'cep-certo-calculo-frete') . '</p>';
    }
    echo '</div>';
}

// Função para renderizar a página "Premium"
function cep_certo_render_premium_page() {
    echo '<div class="wrap">';
    // Caminho para o arquivo premium.php
    $premium_file = plugin_dir_path(__FILE__) . 'premium/premium.php';
    
    if (file_exists($premium_file)) {
        include($premium_file);
    } else {
        echo '<p>' . esc_html__('O arquivo premium.php não foi encontrado.', 'cep-certo-calculo-frete') . '</p>';
    }
    echo '</div>';
}

// Função para salvar o CEP de origem no banco de dados
function cepcerto_salvar_cep_origem() {
    // Verifica se o valor do CEP foi enviado
    if (isset($_POST['cep_origem']) && !empty($_POST['cep_origem'])) {
        $cep_origem = sanitize_text_field($_POST['cep_origem']);

        // Salva o CEP de origem na tabela wp_options
        update_option('cepcerto_cep_origem', $cep_origem);

        // Retorna uma resposta de sucesso para o AJAX
        wp_send_json_success('CEP gravado com sucesso.');
    } else {
        // Retorna uma resposta de erro se o CEP não for enviado
        wp_send_json_error('CEP inválido.');
    }
}
add_action('wp_ajax_cepcerto_salvar_cep_origem', 'cepcerto_salvar_cep_origem');

// Função para desativar o CEP de origem
function cepcerto_desativar_cep_origem() {
    // Verifica se o valor para desativar foi enviado
    if (isset($_POST['desativar_cep']) && $_POST['desativar_cep'] == 1) {
        // Remove a opção da tabela wp_options
        delete_option('cepcerto_cep_origem');

        // Retorna uma resposta de sucesso para o AJAX
        wp_send_json_success('CEP de origem desativado com sucesso.');
    } else {
        // Retorna uma resposta de erro se algo deu errado
        wp_send_json_error('Erro ao desativar o CEP de origem.');
    }
}
add_action('wp_ajax_cepcerto_desativar_cep_origem', 'cepcerto_desativar_cep_origem');

// Função para renderizar o short code
function cep_certo_form_shortcode() {
    ob_start();
    if (file_exists(plugin_dir_path(__FILE__) . 'calculo-frete/form-shortcode.php')) {
        include plugin_dir_path(__FILE__) . 'calculo-frete/form-shortcode.php';
    }
    return ob_get_clean();
}
add_shortcode('cepcerto_form', 'cep_certo_form_shortcode');

// Função para calcular o frete
function calcular_frete() {
    // Recupera a chave da API do banco de dados
    $api_key = get_option('cepcerto_chave');

    // Verifica se todos os campos necessários foram preenchidos
    if (isset($_POST['cep-origem'], $_POST['cep-destino'], $_POST['peso'], $_POST['altura'], $_POST['largura'], $_POST['comprimento'])) {
        // Sanitiza e remove o hífen dos campos CEP
        $cep_origem = str_replace('-', '', sanitize_text_field($_POST['cep-origem']));
        $cep_destino = str_replace('-', '', sanitize_text_field($_POST['cep-destino']));
        $peso = sanitize_text_field($_POST['peso']);
        $altura = sanitize_text_field($_POST['altura']);
        $largura = sanitize_text_field($_POST['largura']);
        $comprimento = sanitize_text_field($_POST['comprimento']);
        
        // Monta a URL da API
        $jsonUrl = "https://cepcerto.com/ws/json-frete/$cep_origem/$cep_destino/$peso/$altura/$largura/$comprimento/$api_key";

        // Faz a chamada para a API
        $jsonContent = file_get_contents($jsonUrl);

        if ($jsonContent !== false) {
            $jsonData = json_decode($jsonContent, true);
            
            if ($jsonData !== null) {
                // Verifica se a API retornou uma mensagem de erro
                if (isset($jsonData['msg'])) {
                    wp_send_json_error($jsonData['msg']);
                }

                // Processa o JSON e exibe os resultados
                $resultado = '
                <div class="result-row">
                    <label>
                        <input type="radio" name="frete" value="PAC">
                        <span class="frete-opcao">PAC:&nbsp;&nbsp;&nbsp;&nbsp; R$' . esc_html($jsonData['valorpac']) . ' - Prazo: ' . esc_html($jsonData['prazopac']) . ' dias</span>
                    </label>
                </div>
                <div class="result-row">
                    <label>
                        <input type="radio" name="frete" value="SEDEX">
                        <span class="frete-opcao">SEDEX: R$' . esc_html($jsonData['valorsedex']) . ' - Prazo: ' . esc_html($jsonData['prazosedex']) . ' dias</span>
                    </label>
                </div>';
                wp_send_json_success(array('resultado' => $resultado, 'url' => $jsonUrl));
            } else {
                wp_send_json_error('Erro: Não foi possível processar os dados retornados da API.');
            }
        } else {
            wp_send_json_error('Erro: Não foi possível se conectar à API.');
        }
    } else {
        wp_send_json_error('Erro: Todos os campos são obrigatórios.');
    }
    
    wp_die(); // Termina a execução
}
add_action('wp_ajax_calcular_frete', 'calcular_frete');
add_action('wp_ajax_nopriv_calcular_frete', 'calcular_frete');