function maskCepInput(event) {
    // Previne que qualquer texto seja solto no campo de entrada
    document.getElementById('cep-origem').addEventListener('drop', function(event) {
    event.preventDefault();
    });
    var input = event.target.value.replace(/\D/g, ''); // Remove todos os caracteres não numéricos
    var maskedInput = '';

    if (input.length > 5) {
        // Formata o CEP no padrão 99999-999
        maskedInput = input.replace(/^(\d{5})(\d{0,3}).*/, '$1-$2');
    } else {
        // Formata os primeiros 5 dígitos do CEP
        maskedInput = input.replace(/^(\d{0,5}).*/, '$1');
    }

    event.target.value = maskedInput; // Atualiza o valor do campo de entrada com a máscara
}

function maskIntegerInput(event) {
    // Previne que qualquer texto seja solto no campo de entrada
    event.target.addEventListener('drop', function(event) {
        event.preventDefault();
    });

    // Remove todos os caracteres que não são dígitos numéricos
    var input = event.target.value.replace(/[^\d]/g, '');

    event.target.value = input; // Atualiza o valor do campo de entrada com a máscara
}

jQuery(document).ready(function($) {
    $('#cadastro-cep-origem').on('submit', function(e) {
        e.preventDefault(); // Evita o recarregamento da página

        var cep = $('#cep-origem').val().replace('-', ''); // Obtém o valor do CEP sem o hífen
        var mensagemRetorno = $('#mensagemretornoceporigem'); // Elemento onde a mensagem será exibida
        var loading = $('#loadingceporigem'); // Exibe a mensagem de carregamento
        mensagemRetorno.html('');
        // Exibe a mensagem de carregamento
        loading.show();

        // Faz a requisição para o ViaCEP
        $.ajax({
            url: 'https://viacep.com.br/ws/' + cep + '/json/', // URL da API ViaCEP
            type: 'GET',
            dataType: 'json',
            success: function(response) {
                if (!('erro' in response)) {

                    // Grava o CEP na tabela wp_options através de uma requisição AJAX para o backend
                    $.ajax({
                        url: ajaxurl, // URL do AJAX do WordPress (disponível automaticamente)
                        type: 'POST',
                        data: {
                            action: 'cepcerto_salvar_cep_origem', // Nome da ação no backend
                            cep_origem: cep
                        },
                        success: function(response) {
                            if (response.success) {
                                mensagemRetorno.html('<span style="color: green;">CEP gravado com sucesso!</span>');
                            } else {
                                mensagemRetorno.html('<span style="color: red;">Erro ao gravar o CEP no banco de dados.</span>');
                            }
                        },
                        error: function() {
                            mensagemRetorno.html('<span style="color: red;">Erro na requisição ao servidor. Tente novamente.</span>');
                        }
                    });
                } else {
                    // O CEP não foi encontrado
                    mensagemRetorno.html('<span style="color: red;">CEP não encontrado.</span>');
                    $('#mensagemretornoceporigem').show();
                }

                // Esconde o carregamento
                loading.hide();
            },
            error: function() {
                loading.hide(); // Esconde o carregamento
                mensagemRetorno.html('<span style="color: red;">Erro na requisição. Tente novamente.</span>');
            }
        });
    });
});

jQuery(document).ready(function($) {
    $('#desativar-cep').on('change', function() {
        if ($(this).is(':checked')) {
            var mensagemRetorno = $('#mensagemretornoceporigem'); // Elemento onde a mensagem será exibida
            var loading = $('#loadingceporigem'); // Exibe a mensagem de carregamento

            // Exibe a mensagem de carregamento
            loading.show();

            // Faz a requisição AJAX para desativar o CEP
            $.ajax({
                url: ajaxurl, // URL do AJAX do WordPress (disponível automaticamente)
                type: 'POST',
                data: {
                    action: 'cepcerto_desativar_cep_origem', // Nome da ação no backend
                    desativar_cep: 1
                },
                success: function(response) {
                    loading.hide(); // Esconde o carregamento

                    if (response.success) {
                        mensagemRetorno.html('<span style="color: green;">' + response.data + '</span>');
                        $('#cep-origem').val("");
                    } else {
                        mensagemRetorno.html('<span style="color: red;">' + response.data + '</span>');
                    }
                },
                error: function() {
                    loading.hide(); // Esconde o carregamento
                    mensagemRetorno.html('<span style="color: red;">Erro ao tentar desativar o CEP. Tente novamente.</span>');
                }
            });
        }
    });
});

jQuery(document).ready(function($) {
    // Captura do elemento onde as mensagens de erro serão exibidas
    var errorMessages = document.getElementById('error-messages');
    var cepOrigemInput = document.getElementById('cep-origem');
    var cepDestinoInput = document.getElementById('cep-destino');
    var pesoInput = document.getElementById('peso');
    var alturaInput = document.getElementById('altura');
    var larguraInput = document.getElementById('largura');
    var comprimentoInput = document.getElementById('comprimento');

    // Função para exibir erros
    function setError(message, element) {
        errorMessages.textContent = message;
        errorMessages.style.opacity = '1';
        errorMessages.style.display = 'block';
        if (element) {
            element.classList.add('input-error');
            element.focus();
        }
    }

    function clearError() {
        errorMessages.textContent = '';
        errorMessages.style.opacity = '0';
        errorMessages.style.display = 'none';
        document.querySelectorAll('.input-error').forEach(el => el.classList.remove('input-error'));
    }

    // Função para validar números (CEP, peso, dimensões)
    function validateNumericInput(value, length) {
        const numericValue = value.replace(/\D/g, ''); // Remove caracteres não numéricos
        return numericValue.length === length ? numericValue : null;
    }

    // Função para validar entradas numéricas genéricas (como peso, dimensões)
    function validateDimension(value) {
        const numericValue = parseFloat(value);
        return !isNaN(numericValue) && numericValue > 0;
    }

    // Limpa o erro quando o usuário começa a digitar ou mudar valores
    document.querySelectorAll('#cepcerto-form input, #cepcerto-form select').forEach(element => {
        element.addEventListener('input', clearError);
        element.addEventListener('change', clearError); // Para selects
    });
    
    // Captura o clique no botão "Calcular Frete"
    $('#calculate-shipping').on('click', function() {
        $('#frete-resultado').css('display', 'none');
        var $button = $(this); // Armazena o botão em uma variável

        // Captura os valores dos campos de CEP e dimensões
        var cepOrigem = $('#cep-origem').val().trim();
        var cepDestino = $('#cep-destino').val().trim();
        var peso = $('#peso').val().trim();
        var altura = parseFloat($('#altura').val().trim());
        var largura = parseFloat($('#largura').val().trim());
        var comprimento = parseFloat($('#comprimento').val().trim());

        // Verifica se os CEPs foram preenchidos
        if (cepOrigem === '' || !validateNumericInput(cepOrigem, 8)) {
            setError('CEP origem inválido', cepOrigemInput);
            return;
        }

        if (cepDestino === '' || !validateNumericInput(cepDestino, 8)) {
            setError('CEP destino inválido', cepDestinoInput);
            return;
        }

        // Verifica se o peso foi preenchido corretamente
        if (!validateDimension(peso)) {
            setError('Peso inválido', pesoInput);
            return;
        }

        // Verifica se a altura foi preenchida corretamente
        if (!validateDimension(altura)) {
            setError('Altura inválida', alturaInput);
            return;
        }

        if (altura > 100) {
            setError('Altura não pode ser maior que 100cm', alturaInput);
            return;
        }

        // Verifica se a largura foi preenchida corretamente
        if (!validateDimension(largura)) {
            setError('Largura inválida', larguraInput);
            return;
        }

        if (largura > 100) {
            setError('Largura não pode ser maior que 100cm', larguraInput);
            return;
        }

        // Verifica se o comprimento foi preenchido corretamente
        if (!validateDimension(comprimento)) {
            setError('Comprimento inválido', comprimentoInput);
            return;
        }

        if (comprimento > 100) {
            setError('Comprimento não pode ser maior que 100cm', comprimentoInput);
            return;
        }

        // Verifica se a soma de altura, largura e comprimento é maior que 200 cm
        var somaDimensoes = altura + largura + comprimento;
        if (somaDimensoes > 200) {
            setError('A soma de altura, largura e comprimento não pode exceder 200cm', alturaInput);
            return;
        }

        // Desabilita o botão, altera o texto e aplica o CSS
        $button.val('Carregando...').prop('disabled', true).css({
            'background-color': '#F9CB40',
            'color': '#0D324D'
        });

        // Prepara os dados para a requisição AJAX
        var data = {
            action: 'calcular_frete',
            'cep-origem': cepOrigem,
            'cep-destino': cepDestino,
            'peso': peso,
            'altura': altura,
            'largura': largura,
            'comprimento': comprimento,
        };

        // Envia a requisição AJAX para o backend do WordPress
        $.post(cepcerto_ajax.ajaxurl, data, function(response) {
            if (response.success) {
                // Exibe o resultado no HTML
                $('#frete-resultado').html(response.data.resultado).css('display', 'block');
                
                // Faz o console log da URL
                console.log('URL chamada para API:', response.data.url);
            } else {
                // Exibe a mensagem de erro retornada pela API
                setError(response.data, null);
            }

            // Restaura o botão ao estado original
            $button.val('Calcular Frete').prop('disabled', false).css({
                'background-color': '',
                'color': ''
            });
        });
    });
});